/*
 * Copyright (c) 2016 ARM Limited
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

#ifndef __MPS2_TOUCHSCREEN_H__
#define __MPS2_TOUCHSCREEN_H__

#ifdef __cplusplus
extern "C" {
#endif

#include <stdint.h>

enum mps2_touch_error_t {
  MPS2_TOUCH_ERR_OK,    /*!< No error */
  MPS2_INVALID_ARG,     /*!< Invalid argument */
  MPS2_FIFO_EMPTY,      /*!< FIFO empty */
  MPS2_I2C_INIT_ERROR,  /*!< I2C initialization error */
  MPS2_I2C_TX_ERROR,    /*!< I2C transmit error */
  MPS2_I2C_RX_ERROR,    /*!< I2C receive error */
};

struct mps2_touch_state_t {
  int16_t x;           /*!< Position X */
  int16_t y;           /*!< Position Y */
  uint8_t pressed;     /*!< Pressed flag */
  uint8_t padding[3];  /*!< to keep 32 bits aligned */
};

/**
 * \brief Initializes MPS2 touchscreen.
 *
 * \returns Returns error code as specified in \ref mps2_touch_error_t
 */
enum mps2_touch_error_t mps2_touch_init(void);

/**
 * \brief Gets touchscreen.
 *
 * \param[out] p_state  Pointer to \ref mps2_touch_state_t structure.
 *
 * \returns Returns error code as specified in \ref mps2_touch_error_t
 */
enum mps2_touch_error_t mps2_touch_get_state(
                                            struct mps2_touch_state_t* p_state);

/**
 * \brief Resets touchscreen FIFO.
 *
 * \returns Returns error code as specified in \ref mps2_touch_error_t
*/
enum mps2_touch_error_t mps2_touch_reset(void);

#ifdef __cplusplus
}
#endif
#endif /* __MPS2_TOUCHSCREEN_H__ */
