/*
 * Copyright (c) 2016 ARM Limited
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

#ifndef __REGION_DEFS_H__
#define __REGION_DEFS_H__

/* Overall constraints */
#define TOTAL_ROM_SIZE (0x00080000) /* 512 KB */
#define TOTAL_RAM_SIZE (0x00020000) /* 128 KB */
#define VENEER_SIZE    (0x00010000) /*  64 KB */

/* Use SRAM1 memory to store Code data */
#define S_ROM_ALIAS_BASE  (0x10000000)
#define NS_ROM_ALIAS_BASE (0x00000000)

/* Use SRAM2 memory to store RW data */
#define S_RAM_ALIAS_BASE  (0x38000000)
#define NS_RAM_ALIAS_BASE (0x28000000)

/* Alias definitions for secure and non-secure areas*/
#define S_ROM_ALIAS(x)  ((S_ROM_ALIAS_BASE)+(x))
#define NS_ROM_ALIAS(x) ((NS_ROM_ALIAS_BASE)+(x))

#define S_RAM_ALIAS(x)  ((S_RAM_ALIAS_BASE)+(x))
#define NS_RAM_ALIAS(x) ((NS_RAM_ALIAS_BASE)+(x))

/* Secure regions */
#define S_CODE_START        ( S_ROM_ALIAS(0x0) )
#define S_CODE_SIZE         ( (TOTAL_ROM_SIZE/2) - VENEER_SIZE )
#define S_CODE_LIMIT        ( S_CODE_START + S_CODE_SIZE )

#define S_DATA_START        ( S_RAM_ALIAS(0x0) )
#define S_DATA_SIZE         ( TOTAL_RAM_SIZE/2 )
#define S_DATA_LIMIT        ( S_DATA_START + S_DATA_SIZE )

/* Non-secure regions */
#define NS_CODE_START       ( NS_ROM_ALIAS(TOTAL_ROM_SIZE/2) )
#define NS_CODE_SIZE        ( TOTAL_ROM_SIZE/2 )
#define NS_CODE_LIMIT       ( NS_CODE_START + NS_CODE_SIZE )

#define NS_DATA_START       ( NS_RAM_ALIAS(TOTAL_RAM_SIZE/2) )
#define NS_DATA_SIZE        ( TOTAL_RAM_SIZE/2 )
#define NS_DATA_LIMIT       ( NS_DATA_START + NS_DATA_SIZE )

/* Veneer region */
#define VENEER_START       ( S_ROM_ALIAS(S_CODE_SIZE) )
#define VENEER_LIMIT       ( VENEER_START + VENEER_SIZE )

#endif /*__REGION_DEFS_H__*/

