/*
 * Copyright (c) 2016-2017 ARM Limited
 *
 * Licensed under the Apache License Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing software
 * distributed under the License is distributed on an "AS IS" BASIS
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

/**
 * \file platform_retarget_dev.h
 * \brief This file defines exports the structures based on the peripheral
 * definitions from device_cfg.h.
 * This retarget file is meant to be used as a helper for baremetal
 * applications and/or as an example of how to configure the generic
 * driver structures.
 */

#ifndef __ARM_LTD_SSE_200_RETARGET_DEV_H__
#define __ARM_LTD_SSE_200_RETARGET_DEV_H__

#include "device_cfg.h"

/* ======= Includes generic driver headers ======= */
#include "arm_i2c_sbcon_drv.h"
#include "arm_gpio_drv.h"
#include "arm_mps2_io_drv.h"
#include "mpc_sie200_drv.h"
#include "ppc_sse200_drv.h"
#include "spi_pl022_drv.h"
#include "arm_uart_drv.h"
#include "arm_watchdog_drv.h"
#include "apb_dualtimer_drv.h"
#include "apb_timer_drv.h"

/* ======= Defines peripheral configuration structures ======= */
/* ARM GPIO driver structures */
#ifdef ARM_GPIO0_S
extern struct arm_gpio_dev_t ARM_GPIO0_DEV_S;
#endif
#ifdef ARM_GPIO0_NS
extern struct arm_gpio_dev_t ARM_GPIO0_DEV_NS;
#endif

#ifdef ARM_GPIO1_S
extern struct arm_gpio_dev_t ARM_GPIO1_DEV_S;
#endif
#ifdef ARM_GPIO1_NS
extern struct arm_gpio_dev_t ARM_GPIO1_DEV_NS;
#endif

#ifdef ARM_GPIO2_S
extern struct arm_gpio_dev_t ARM_GPIO2_DEV_S;
#endif
#ifdef ARM_GPIO2_NS
extern struct arm_gpio_dev_t ARM_GPIO2_DEV_NS;
#endif

#ifdef ARM_GPIO3_S
extern struct arm_gpio_dev_t ARM_GPIO3_DEV_S;
#endif
#ifdef ARM_GPIO3_NS
extern struct arm_gpio_dev_t ARM_GPIO3_DEV_NS;
#endif

/* ARM I2C SBCon driver structures */
#ifdef ARM_I2C0_SBCON_S
extern struct arm_i2c_sbcon_dev_t ARM_I2C0_SBCON_DEV_S;
#endif
#ifdef ARM_I2C0_SBCON_NS
extern struct arm_i2c_sbcon_dev_t ARM_I2C0_SBCON_DEV_NS;
#endif

#ifdef ARM_I2C1_SBCON_S
extern struct arm_i2c_sbcon_dev_t ARM_I2C1_SBCON_DEV_S;
#endif
#ifdef ARM_I2C1_SBCON_NS
extern struct arm_i2c_sbcon_dev_t ARM_I2C1_SBCON_DEV_NS;
#endif

#ifdef ARM_I2C2_SBCON_S
extern struct arm_i2c_sbcon_dev_t ARM_I2C2_SBCON_DEV_S;
#endif
#ifdef ARM_I2C2_SBCON_NS
extern struct arm_i2c_sbcon_dev_t ARM_I2C2_SBCON_DEV_NS;
#endif

#ifdef ARM_I2C3_SBCON_S
extern struct arm_i2c_sbcon_dev_t ARM_I2C3_SBCON_DEV_S;
#endif
#ifdef ARM_I2C3_SBCON_NS
extern struct arm_i2c_sbcon_dev_t ARM_I2C3_SBCON_DEV_NS;
#endif

/* ARM MPS2 IO FPGAIO driver structures */
#ifdef ARM_MPS2_IO_FPGAIO_S
extern struct arm_mps2_io_dev_t ARM_MPS2_IO_FPGAIO_DEV_S;
#endif
#ifdef ARM_MPS2_IO_FPGAIO_NS
extern struct arm_mps2_io_dev_t ARM_MPS2_IO_FPGAIO_DEV_NS;
#endif

/* ARM MPS2 IO SCC driver structures */
#ifdef ARM_MPS2_IO_SCC_S
extern struct arm_mps2_io_dev_t ARM_MPS2_IO_SCC_DEV_S;
#endif
#ifdef ARM_MPS2_IO_SCC_NS
extern struct arm_mps2_io_dev_t ARM_MPS2_IO_SCC_DEV_NS;
#endif

/* ARM UART driver structures */
#ifdef ARM_UART0_S
extern struct arm_uart_dev_t ARM_UART0_DEV_S;
#endif
#ifdef ARM_UART0_NS
extern struct arm_uart_dev_t ARM_UART0_DEV_NS;
#endif

#ifdef ARM_UART1_S
extern struct arm_uart_dev_t ARM_UART1_DEV_S;
#endif
#ifdef ARM_UART1_NS
extern struct arm_uart_dev_t ARM_UART1_DEV_NS;
#endif

#ifdef ARM_UART2_S
extern struct arm_uart_dev_t ARM_UART2_DEV_S;
#endif
#ifdef ARM_UART2_NS
extern struct arm_uart_dev_t ARM_UART2_DEV_NS;
#endif

#ifdef ARM_UART3_S
extern struct arm_uart_dev_t ARM_UART3_DEV_S;
#endif
#ifdef ARM_UART3_NS
extern struct arm_uart_dev_t ARM_UART3_DEV_NS;
#endif

#ifdef ARM_UART4_S
extern struct arm_uart_dev_t ARM_UART4_DEV_S;
#endif
#ifdef ARM_UART4_NS
extern struct arm_uart_dev_t ARM_UART4_DEV_NS;
#endif

/* ARM Watchdog driver structures */
#ifdef APB_WATCHDOG_S
extern struct arm_watchdog_dev_t APB_WATCHDOG_DEV_S;
#endif
#ifdef APB_WATCHDOG_NS
extern struct arm_watchdog_dev_t APB_WATCHDOG_DEV_NS;
#endif

#ifdef S32K_WATCHDOG_S
extern struct arm_watchdog_dev_t S32K_WATCHDOG_DEV_S;
#endif
#ifdef S32K_WATCHDOG_NS
extern struct arm_watchdog_dev_t S32K_WATCHDOG_DEV_NS;
#endif

/* APB Dualtimer driver structures */
#ifdef APB_DUALTIMER_S
extern struct apb_dualtimer_dev_t APB_DUALTIMER_DEV_S;
#endif
#ifdef APB_DUALTIMER_NS
extern struct apb_dualtimer_dev_t APB_DUALTIMER_DEV_NS;
#endif

/* ARM PPC driver structures */
#ifdef AHB_PPC0_S
extern struct ppc_sse200_dev_t AHB_PPC0_DEV_S;
#endif

#ifdef AHB_PPCEXP0_S
extern struct ppc_sse200_dev_t AHB_PPCEXP0_DEV_S;
#endif

#ifdef AHB_PPCEXP1_S
extern struct ppc_sie200_dev_t AHB_PPCEXP1_DEV_S;
#endif

#ifdef AHB_PPCEXP2_S
extern struct ppc_sse200_dev_t AHB_PPCEXP2_DEV_S;
#endif

#ifdef AHB_PPCEXP3_S
extern struct ppc_sse200_dev_t AHB_PPCEXP3_DEV_S;
#endif

#ifdef APB_PPC0_S
extern struct ppc_sse200_dev_t APB_PPC0_DEV_S;
#endif

#ifdef APB_PPC1_S
extern struct ppc_sse200_dev_t APB_PPC1_DEV_S;
#endif

#ifdef APB_PPCEXP0_S
extern struct ppc_sse200_dev_t APB_PPCEXP0_DEV_S;
#endif

#ifdef APB_PPCEXP1_S
extern struct ppc_sse200_dev_t APB_PPCEXP1_DEV_S;
#endif

#ifdef APB_PPCEXP2_S
extern struct ppc_sse200_dev_t APB_PPCEXP2_DEV_S;
#endif

#ifdef APB_PPCEXP3_S
extern struct ppc_sse200_dev_t APB_PPCEXP3_DEV_S;
#endif

/* APB Timer driver structures */
#ifdef APB_TIMER0_S
extern struct apb_timer_dev_t APB_TIMER0_DEV_S;
#endif
#ifdef APB_TIMER0_NS
extern struct apb_timer_dev_t APB_TIMER0_DEV_NS;
#endif

#ifdef APB_TIMER1_S
extern struct apb_timer_dev_t APB_TIMER1_DEV_S;
#endif
#ifdef APB_TIMER1_NS
extern struct apb_timer_dev_t APB_TIMER1_DEV_NS;
#endif

/* ARM MPC SSE 200 driver structures */
#ifdef MPC_ISRAM0_S
extern struct mpc_sie200_dev_t MPC_ISRAM0_DEV_S;
#endif

#ifdef MPC_ISRAM1_S
extern struct mpc_sie200_dev_t MPC_ISRAM1_DEV_S;
#endif

#ifdef MPC_ISRAM2_S
extern struct mpc_sie200_dev_t MPC_ISRAM2_DEV_S;
#endif

#ifdef MPC_ISRAM3_S
extern struct mpc_sie200_dev_t MPC_ISRAM3_DEV_S;
#endif

#ifdef MPC_SRAM1_S
extern struct mpc_sie200_dev_t MPC_SRAM1_DEV_S;
#endif

#ifdef MPC_SRAM2_S
extern struct mpc_sie200_dev_t MPC_SRAM2_DEV_S;
#endif

#ifdef MPC_SRAM3_S
extern struct mpc_sie200_dev_t MPC_SRAM3_DEV_S;
#endif

/* ARM SPI driver structures */
#ifdef SPI0_PL022_S
extern struct spi_pl022_dev_t SPI0_PL022_DEV_S;
#endif
#ifdef SPI0_PL022_NS
extern struct spi_pl022_dev_t SPI0_PL022_DEV_NS;
#endif

#ifdef SPI1_PL022_S
extern struct spi_pl022_dev_t SPI1_PL022_DEV_S;
#endif
#ifdef SPI1_PL022_NS
extern struct spi_pl022_dev_t SPI1_PL022_DEV_NS;
#endif

#ifdef SPI2_PL022_S
extern struct spi_pl022_dev_t SPI2_PL022_DEV_S;
#endif
#ifdef SPI2_PL022_NS
extern struct spi_pl022_dev_t SPI2_PL022_DEV_NS;
#endif

#ifdef SPI3_PL022_S
extern struct spi_pl022_dev_t SPI3_PL022_DEV_S;
#endif
#ifdef SPI3_PL022_NS
extern struct spi_pl022_dev_t SPI3_PL022_DEV_NS;
#endif

#ifdef SPI4_PL022_S
extern struct spi_pl022_dev_t SPI4_PL022_DEV_S;
#endif
#ifdef SPI4_PL022_NS
extern struct spi_pl022_dev_t SPI4_PL022_DEV_NS;
#endif

#endif  /* __ARM_LTD_SSE_200_RETARGET_DEV_H__ */
